//
// Module: RatioPsfModel
// Author: Richard Saxton
//
// Description: 
//
// A simple model for the PSF.
// Used for prototyping; will be eventually replaced by relevant CAL fn.
//
// Modifications: See ChangeLog
// 
// $Id: RatioPsfModel.h,v 1.1.1.1 2004/02/09 14:54:12 eojero Exp $

#ifndef RatioPsfModel_H
#define RatioPsfModel_H

/* SAS-specific */
#include "CalCommon.h"
#include "CalServer.h"
#include "EncircledEnergyDataServer.h"
#include "Region.h"

/* Local */
#include "PsfModel.h"

class RatioPsfModel: public PsfModel
{
public:

  /*** NOTE: units for both x/y directions are 0.05 arcseconds ***/

  /* Constructor */
   RatioPsfModel( int TotalPixels          /* No of pixels in integration */
                    );    

  /* Destructor */
  ~RatioPsfModel();

  /* Return normalized PSF function at given position */
  double psf( double x, 
	      double y) const;
  
  /* Calculate integrated PSF over a square area. The position of the centre
 * of the square is defined by the parameters centx and centy.
 * The method divides the area into nbins*nbins subelements
 * for the computation.
 * The higher nbins is, the more accurate the computation will be.
 */
  double int_psf( double xboxcentre, 
		  double yboxcentre, 
		  double xboxsize,
		  double yboxsize) const;

  double rad_psf() const;

  void energy(double energy);

  void setRadius(vector<double> radii);

  void setNgridEls(unsigned int NGridEls);

  string mode() const;

  void setBoxShape(ShapeBasics::ShapeType shape);

private:
  
  int _totalpixels;

};

#endif

