// This  skeleton file was automatically created by 
//            pkgmaker 0.1
//            Thursday, December 11 1997
// 
// Module: SetBackScale
// Author: Richard Saxton
//
// Description: Writes the BACKSCAL value into the input spectrum
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 

// General classes

// SAS-specific classes
#include "Dal.h"
#include "OalServer.h"
#include "param.h"

// General utility functions
#include "Tracer.h"

// Local Classes
#include "SetBackScale.h"
#include "ArfDataServer.h"

/* Constructor */


SetBackScale::SetBackScale() 
{
  PROC;

  /* Open spectrum dataset */
  string spectrumsetname = stringParameter("spectrumset");
  errstr 
    << "Opening spectrumset " << spectrumsetname << "..."
    << Sas::message(Msg::App, Msg::Sparse);
  
  DataSet * spectrumset = 
    dataSetServer->open( spectrumsetname, 
			 DataSet::Modify );
  
  errstr 
    << "Opened spectrumset " << spectrumsetname << "..."
    << Sas::message(Msg::App, Msg::Sparse);

  /* Access spectrum  */
  Table * spectrumtable = spectrumset->table("SPECTRUM", Dal::Modify); 
  
  errstr 
    << "Opened table " << spectrumsetname << "..."
    << Sas::message(Msg::App, Msg::Sparse);

  errstr 
    << "current backscale value is: "<<spectrumtable->attribute("BACKSCAL")->asString()
    << Sas::message(Msg::App, Msg::Sparse);

  /* If backscale keyword already exists remove it */
  if (spectrumtable->hasAttribute("BACKSCAL"))
  {
       spectrumtable->deleteAttribute("BACKSCAL");
  errstr 
    << "deleted att" << spectrumsetname << "..."
    << Sas::message(Msg::App, Msg::Sparse);
  }

  /* Now add the backscale value */
  int backscale = arfDataServer->backScale();

  /* If negative rest to zero */
  if ( backscale < 0 )
  {
     errstr << "Calculated BACKSCAL value is negative ("<<backscale<<") - "
            << "resetting to zero" << Sas::warning("NegBackscale");
     backscale=0;
  }

  errstr 
    << "Backscale value is: "<<backscale
    << Sas::message(Msg::App, Msg::Sparse);

  * spectrumtable->addAttribute("BACKSCAL", "Scaling factor for background") =
                       backscale;

  errstr 
    << "added att" << spectrumsetname << "..."
    << Sas::message(Msg::App, Msg::Sparse);

  /* Close the spectrum */
  dataSetServer->close(spectrumset);

  errstr 
    << "closed spec" << spectrumsetname << "..."
    << Sas::message(Msg::App, Msg::Sparse);

  ENDPROC;

}

